===================
Quantum Walk Models
===================

.. currentmodule:: hiperwalk

Classes
-------
.. autosummary::
    :toctree: generated
    :nosignatures:

    QuantumWalk
    Coined
    ContinuousTime
